clc, clear, close all, format compact

%% Eelectric specifications
Ua = 240; %[V] armature voltage
Uf = 300; %[V] field voltage
Ra = 11.2; %[ohm] armature resistance
La = 0.1215; %[H] armature inductance
Rf = 281.3; %[ohm] field reistance
Lf = 156; %[H] field inductance
Laf = 1.976; %[H] mutual inductance

%% Mechanical spicifications
J = 0.02215; % [kgm^2] total inertia
Bm = 0.002953; % viscous friction
Tf = 0.5161; % coulomb friction
w0 =0; % [rad/s] initial speed
TL = 0; % [Nm] torque load

%% Start simulation
DC_start = sim('Dopredny_model_DC_motor');

%% Plot 
%Budiace napatie
t = Ua_dnm.time;
Ua_dnm = Ua_dnm.signals(1).values;
figure(1)
plot(t,Ua_dnm,'LineWidth',1.5)
ylim([-250 250])
title('Naptie na DC motore')
xlabel('t[s]')
ylabel('Ua[V]')
%uhlova rychlost motora, uhlova rychlost(vystup z NN)motora
w_dnm1 = w_dnm.signals(1).values;
w_dnm2 = w_dnm.signals(2).values;
figure(2)
plot(t,w_dnm1,'k','LineWidth',1.5)
hold on
plot(t,w_dnm2,'r')
ylim([-150 180])
title('Uhlov rchlos')
xlabel('t[s]')
ylabel('w[rads^-1]')
legend('w - skuton hodnota','w - vstup z doprednho modelu')
% Pozicia a velkost okna detailu
x_r = 6.3; y_r = 29; w_r = 1.7; h_r = 65;
rectangle('Position', [x_r-w_r/2, y_r-h_r/2, w_r, h_r], ...
          'EdgeColor', [0.4, 0.1, 0.4]);
% Pozicia a velkost 2. osy
x_a = 0.18; y_a = 0.71; w_a = 0.2; h_a = 0.2;
ax = axes('Units', 'Normalized', ...
          'Position', [x_a, y_a, w_a, h_a], ...
          'XTick', [], ...
          'YTick', [], ...
          'Box', 'on', ...
          'LineWidth', 1, ...
          'Color', [0.95, 0.99, 0.95]);
plot(t,w_dnm1,'k','LineWidth',1.5)
grid on
hold on
plot(t,w_dnm2,'r');
axis([x_r-w_r/2, x_r+w_r/2, y_r-h_r/2, y_r+h_r/2]);
%% Rozdielovy graf
w_rozdiel = w_dnm1 - w_dnm2;
figure(3)
plot(t,w_rozdiel)






